pub struct BuyerRequestedCancel {
pub is_buyer_requested_cancel: Option<bool>,
pub buyer_cancel_reason: Option<String>,
}Expand description
BuyerRequestedCancel : Information about whether or not a buyer requested cancellation.
Fields
is_buyer_requested_cancel: Option<bool>When true, the buyer has requested cancellation.
buyer_cancel_reason: Option<String>The reason that the buyer requested cancellation.
Implementations
sourceimpl BuyerRequestedCancel
impl BuyerRequestedCancel
sourcepub fn new() -> BuyerRequestedCancel
pub fn new() -> BuyerRequestedCancel
Information about whether or not a buyer requested cancellation.